@@ -16,19 +16,23 @@
 
 namespace
 {
-decltype(hip_init)*       hip_init_fn       = nullptr;
-decltype(hsa_init)*       hsa_init_fn       = nullptr;
-decltype(ncclGetVersion)* ncclGetVersion_fn = nullptr;
-decltype(roctxRangePush)* roctxRangePush_fn = nullptr;
-decltype(roctxRangePush)* roctxRangePop_fn  = nullptr;
+decltype(hip_init)*            hip_init_fn            = nullptr;
+decltype(hsa_init)*            hsa_init_fn            = nullptr;
+decltype(ncclGetVersion)*      ncclGetVersion_fn      = nullptr;
+decltype(roctxRangePush)*      roctxRangePush_fn      = nullptr;
+decltype(roctxRangePush)*      roctxRangePop_fn       = nullptr;
+decltype(rocDecCreateDecoder)* rocDecCreateDecoder_fn = nullptr;
+decltype(rocJpegStreamCreate)* rocJpegStreamCreate_fn = nullptr;
 
 enum rocp_reg_test_modes : uint8_t
 {
-    ROCP_REG_TEST_NONE  = 0x0,
-    ROCP_REG_TEST_HIP   = (1 << 0),
-    ROCP_REG_TEST_HSA   = (1 << 1),
-    ROCP_REG_TEST_ROCTX = (1 << 2),
-    ROCP_REG_TEST_RCCL  = (1 << 3),
+    ROCP_REG_TEST_NONE      = 0x0,
+    ROCP_REG_TEST_HIP       = (1 << 0),
+    ROCP_REG_TEST_HSA       = (1 << 1),
+    ROCP_REG_TEST_ROCTX     = (1 << 2),
+    ROCP_REG_TEST_RCCL      = (1 << 3),
+    ROCP_REG_TEST_ROCDECODE = (1 << 4),
+    ROCP_REG_TEST_ROCJPEG   = (1 << 5),
 };
 
 template <uint8_t Idx = ROCP_REG_TEST_NONE>
@@ -72,10 +76,12 @@ resolve_symbols(int _open_mode = RTLD_LOCAL | RTLD_LAZY)
         }
     };
 
-    void* amdhip_handle = nullptr;
-    void* hsart_handle  = nullptr;
-    void* roctx_handle  = nullptr;
-    void* rccl_handle   = nullptr;
+    void* amdhip_handle    = nullptr;
+    void* hsart_handle     = nullptr;
+    void* roctx_handle     = nullptr;
+    void* rccl_handle      = nullptr;
+    void* rocdecode_handle = nullptr;
+    void* rocjpeg_handle   = nullptr;
 
     if constexpr((Idx & ROCP_REG_TEST_HIP) == ROCP_REG_TEST_HIP)
     {
@@ -107,5 +113,19 @@ resolve_symbols(int _open_mode = RTLD_LOCAL | RTLD_LAZY)
         if(!ncclGetVersion_fn) _resolve_dlopen(rccl_handle, "librccl.so");
         _resolve_dlsym(ncclGetVersion_fn, rccl_handle, "ncclGetVersion");
     }
+
+    if constexpr((Idx & ROCP_REG_TEST_ROCDECODE) == ROCP_REG_TEST_ROCDECODE)
+    {
+        rocDecCreateDecoder_fn = rocDecCreateDecoder;
+        if(!rocDecCreateDecoder_fn) _resolve_dlopen(rocdecode_handle, "librocdecode.so");
+        _resolve_dlsym(rocDecCreateDecoder_fn, rocdecode_handle, "rocDecCreateDecoder");
+    }
+
+    if constexpr((Idx & ROCP_REG_TEST_ROCJPEG) == ROCP_REG_TEST_ROCJPEG)
+    {
+        rocJpegStreamCreate_fn = rocJpegStreamCreate;
+        if(!rocJpegStreamCreate_fn) _resolve_dlopen(rocjpeg_handle, "librocjpeg.so");
+        _resolve_dlsym(rocJpegStreamCreate_fn, rocjpeg_handle, "rocJpegStreamCreate");
+    }
 }
 }  // namespace
